# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["VideoSize"]

VideoSize: TypeAlias = Literal["720x1280", "1280x720", "1024x1792", "1792x1024"]
