# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Literal, Required, TypedDict

from .tool_param import ToolParam

__all__ = ["ResponseToolSearchOutputItemParamParam"]


class ResponseToolSearchOutputItemParamParam(TypedDict, total=False):
    tools: Required[Iterable[ToolParam]]
    """The loaded tool definitions returned by the tool search output."""

    type: Required[Literal["tool_search_output"]]
    """The item type. Always `tool_search_output`."""

    id: Optional[str]
    """The unique ID of this tool search output."""

    call_id: Optional[str]
    """The unique ID of the tool search call generated by the model."""

    execution: Literal["server", "client"]
    """Whether tool search was executed by the server or by the client."""

    status: Optional[Literal["in_progress", "completed", "incomplete"]]
    """The status of the tool search output."""
