# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .beta_response_function_call_output_item import BetaResponseFunctionCallOutputItem

__all__ = ["BetaResponseFunctionCallOutputItemList"]

BetaResponseFunctionCallOutputItemList: TypeAlias = List[BetaResponseFunctionCallOutputItem]
