# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .webhooks import Webhooks as _Webhooks, AsyncWebhooks as _AsyncWebhooks


class Webhooks(_Webhooks):
    pass


class AsyncWebhooks(_AsyncWebhooks):
    pass


__all__ = ["Webhooks", "AsyncWebhooks"]
