# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .response_input_item import ResponseInputItem

__all__ = ["ResponseInput"]

ResponseInput: TypeAlias = List[ResponseInputItem]
