# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .beta_response_input_content import BetaResponseInputContent

__all__ = ["BetaResponseInputMessageContentList"]

BetaResponseInputMessageContentList: TypeAlias = List[BetaResponseInputContent]
