# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["ResponseToolSearchCall"]


class ResponseToolSearchCall(BaseModel):
    id: str
    """The unique ID of the tool search call item."""

    arguments: object
    """Arguments used for the tool search call."""

    call_id: Optional[str] = None
    """The unique ID of the tool search call generated by the model."""

    execution: Literal["server", "client"]
    """Whether tool search was executed by the server or by the client."""

    status: Literal["in_progress", "completed", "incomplete"]
    """The status of the tool search call item that was recorded."""

    type: Literal["tool_search_call"]
    """The type of the item. Always `tool_search_call`."""

    created_by: Optional[str] = None
    """The identifier of the actor that created the item."""
